@@ -3,7 +3,8 @@
 from abc import ABC, abstractmethod
 from .algo import Algo
 from .predictor import Predictor
-from .types import Metatype
+from .types import Metatype, PredictionMethod, is_classification_metatype, is_prediction_method
+from .errors import ValidationError
 
 INPUT_METATYPES = {Metatype.NUMERICAL, Metatype.CATEGORICAL, Metatype.BINARY,
             Metatype.DATETIME, Metatype.TIMESTAMP, Metatype.DELIM_PIPE, Metatype.DELIM_SEMICOLON}
@@ -15,6 +16,17 @@ class TabularClassifier(Predictor, ABC):
     Note:
         'predict_proba' and 'decision_function' are optional, but should be implemented if possible.
     """
+    @staticmethod
+    @abstractmethod
+    def prediction_methods():
+        """
+        Describes the prediction_methods that the classifier supports.
+        
+        Returns: 
+            Set of PredictionMethods.
+        """
+        pass
+
     @abstractmethod
     def predict(self, X):
         """
@@ -76,8 +88,9 @@ class TabularClassificationAutoML(Algo, TabularClassifier, ABC):
         """
         pass
 
+    @staticmethod
     @abstractmethod
-    def input_metatypes(self):
+    def input_metatypes():
         """
         Describes the X_metatypes that the algo supports.
         
@@ -86,8 +99,9 @@ class TabularClassificationAutoML(Algo, TabularClassifier, ABC):
         """
         pass
 
+    @staticmethod
     @abstractmethod
-    def target_metatype(self):
+    def target_metatype():
         """
         Describes the y_metatype that the algo supports.
         
@@ -96,8 +110,9 @@ class TabularClassificationAutoML(Algo, TabularClassifier, ABC):
         """
         pass
 
+    @staticmethod
     @abstractmethod
-    def is_multioutput(self):
+    def is_multioutput():
         """
         Returns true if the algo supports mulitple outputs.
         
@@ -139,8 +154,9 @@ class TabularRegressionAutoML(Algo, TabularRegressor, ABC):
         """
         pass
 
+    @staticmethod
     @abstractmethod
-    def input_metatypes(self):
+    def input_metatypes():
         """
         Describes the X_metatypes that the algo supports.
         
@@ -149,8 +165,9 @@ class TabularRegressionAutoML(Algo, TabularRegressor, ABC):
         """
         pass
 
+    @staticmethod
     @abstractmethod
-    def is_multioutput(self):
+    def is_multioutput():
         """
         Returns true if the algo supports mulitple outputs.
         
@@ -178,3 +195,54 @@ def is_input_metatype(metatype, strict = False):
     except ValueError:
         return False
 
+def extract_statics(obj):
+    statics = dict()
+
+    if issubclass(obj, TabularClassificationAutoML) or issubclass(obj, TabularRegressionAutoML):
+        input_metatypes = obj.input_metatypes()
+        if not isinstance(input_metatypes, set) or not input_metatypes:
+            raise ValidationError('input_metatypes must be a non-empty set')
+
+        for metatype in input_metatypes:
+            if not is_input_metatype(metatype, True):
+                raise ValidationError('invalid input metatype')
+
+        statics['input_metatypes'] = sorted(list(input_metatypes), key=lambda x: x.name)
+
+        is_multioutput = obj.is_multioutput()
+        if not isinstance(is_multioutput, bool):
+            raise ValidationError('is_multioutput should return bool')
+
+        statics['is_multioutput'] = is_multioutput
+
+        if isinstance(obj, TabularClassificationAutoML):
+            target_metatype = obj.target_metatype()
+            if not is_classification_metatype(target_metatype):
+                raise ValidationError('invalid classification metatype')
+
+            statics['target_metatype'] = target_metatype
+
+
+    if issubclass(obj, TabularClassifier):
+        prediction_methods = obj.prediction_methods()
+        if not isinstance(prediction_methods, set) or not prediction_methods:
+            raise ValidationError('prediction_methods must be a non-empty set')
+
+        for prediction_method in prediction_methods:
+            if not is_prediction_method(prediction_method, True):
+                raise ValidationError('invalid prediction method')
+
+        if PredictionMethod.PREDICT not in prediction_methods:
+            raise ValidationError('predict missing from prediction method')
+
+        if PredictionMethod.PREDICT_PROBA in prediction_methods and PredictionMethod.DECISION_FUNCTION not in prediction_methods:
+            raise ValidationError('if predict_proba is in prediction_methods, then decision_function should also be')
+
+    else:
+        prediction_methods = { PredictionMethod.PREDICT }
+
+    statics['prediction_methods'] = sorted([prediction_method.name.lower() for prediction_method in prediction_methods])
+
+    return statics
+
+    
\ No newline at end of file
